{% extends "kleides_mfa/base.html" %}

{% load crispy_forms_tags i18n %}

{% block content %}
<h1>{% trans 'Login' %}</h1>

{% block form_description %}{% endblock form_description %}

<form id="kleides-mfa-form" action="" method="post" novalidate>{% csrf_token %}
    {{ form|crispy }}

    <button class='btn btn-primary' type='submit'>{% trans 'Login' %}</button>
</form>
{% endblock content %}
